# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server/v1/observability.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ...openapiv3 import annotations_pb2 as openapiv3_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dserver/v1/observability.proto\x12\x1btigrisdata.observability.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1bopenapiv3/annotations.proto\"\x1a\n\tRetryInfo\x12\r\n\x05\x64\x65lay\x18\x03 \x01(\x05\"d\n\x0c\x45rrorDetails\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x05retry\x18\x03 \x01(\x0b\x32&.tigrisdata.observability.v1.RetryInfo\"I\n\x05\x45rror\x12/\n\x04\x63ode\x18\x01 \x01(\x0e\x32!.tigrisdata.observability.v1.Code\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xdc\x03\n\x1dQueryTimeSeriesMetricsRequest\x12\n\n\x02\x64\x62\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\x12\x0c\n\x04\x66rom\x18\x04 \x01(\x03\x12\n\n\x02to\x18\x05 \x01(\x03\x12\x13\n\x0bmetric_name\x18\x06 \x01(\t\x12\x46\n\x10tigris_operation\x18\x07 \x01(\x0e\x32,.tigrisdata.observability.v1.TigrisOperation\x12S\n\x11space_aggregation\x18\x08 \x01(\x0e\x32\x38.tigrisdata.observability.v1.MetricQuerySpaceAggregation\x12\x1b\n\x13space_aggregated_by\x18\t \x03(\t\x12\x42\n\x08\x66unction\x18\n \x01(\x0e\x32\x30.tigrisdata.observability.v1.MetricQueryFunction\x12\x10\n\x08quantile\x18\x0b \x01(\x02\x12L\n\x13\x61\x64\x64itionalFunctions\x18\x0c \x03(\x0b\x32/.tigrisdata.observability.v1.AdditionalFunction\"a\n\x12\x41\x64\x64itionalFunction\x12@\n\x06rollup\x18\x01 \x01(\x0b\x32+.tigrisdata.observability.v1.RollupFunctionH\x00\x88\x01\x01\x42\t\n\x07_rollup\"e\n\x0eRollupFunction\x12\x41\n\naggregator\x18\x01 \x01(\x0e\x32-.tigrisdata.observability.v1.RollupAggregator\x12\x10\n\x08interval\x18\x02 \x01(\x03\"\x84\x01\n\x1eQueryTimeSeriesMetricsResponse\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\x12\r\n\x05query\x18\x03 \x01(\t\x12\x39\n\x06series\x18\x04 \x03(\x0b\x32).tigrisdata.observability.v1.MetricSeries\"\x83\x01\n\x0cMetricSeries\x12\x0c\n\x04\x66rom\x18\x01 \x01(\x03\x12\n\n\x02to\x18\x02 \x01(\x03\x12\x0e\n\x06metric\x18\x03 \x01(\t\x12\r\n\x05scope\x18\x04 \x01(\t\x12:\n\ndataPoints\x18\x05 \x03(\x0b\x32&.tigrisdata.observability.v1.DataPoint\"-\n\tDataPoint\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x01\"\x14\n\x12QuotaLimitsRequest\"Q\n\x13QuotaLimitsResponse\x12\x11\n\tReadUnits\x18\x01 \x01(\x03\x12\x12\n\nWriteUnits\x18\x02 \x01(\x03\x12\x13\n\x0bStorageSize\x18\x03 \x01(\x03\"\x13\n\x11QuotaUsageRequest\"\xa7\x01\n\x12QuotaUsageResponse\x12\x11\n\tReadUnits\x18\x01 \x01(\x03\x12\x12\n\nWriteUnits\x18\x02 \x01(\x03\x12\x13\n\x0bStorageSize\x18\x03 \x01(\x03\x12\x1a\n\x12ReadUnitsThrottled\x18\x04 \x01(\x03\x12\x1b\n\x13WriteUnitsThrottled\x18\x05 \x01(\x03\x12\x1c\n\x14StorageSizeThrottled\x18\x06 \x01(\x03\"\x10\n\x0eGetInfoRequest\"\\\n\x0fGetInfoResponse\x12\x16\n\x0eserver_version\x18\x01 \x01(\t\x12\x31\n\x05\x65rror\x18\x02 \x01(\x0b\x32\".tigrisdata.observability.v1.Error*\x85\x03\n\x04\x43ode\x12\x06\n\x02OK\x10\x00\x12\r\n\tCANCELLED\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\x12\x14\n\x10INVALID_ARGUMENT\x10\x03\x12\x15\n\x11\x44\x45\x41\x44LINE_EXCEEDED\x10\x04\x12\r\n\tNOT_FOUND\x10\x05\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x06\x12\x15\n\x11PERMISSION_DENIED\x10\x07\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x08\x12\x17\n\x13\x46\x41ILED_PRECONDITION\x10\t\x12\x0b\n\x07\x41\x42ORTED\x10\n\x12\x10\n\x0cOUT_OF_RANGE\x10\x0b\x12\x11\n\rUNIMPLEMENTED\x10\x0c\x12\x0c\n\x08INTERNAL\x10\r\x12\x0f\n\x0bUNAVAILABLE\x10\x0e\x12\r\n\tDATA_LOSS\x10\x0f\x12\x13\n\x0fUNAUTHENTICATED\x10\x10\x12\x0c\n\x08\x43ONFLICT\x10\x11\x12\x0f\n\x0b\x42\x41\x44_GATEWAY\x10\x12\x12\x16\n\x12METHOD_NOT_ALLOWED\x10\x13\x12\x15\n\x11\x43ONTENT_TOO_LARGE\x10\x14*=\n\x0fTigrisOperation\x12\x07\n\x03\x41LL\x10\x00\x12\x08\n\x04READ\x10\x01\x12\t\n\x05WRITE\x10\x02\x12\x0c\n\x08METADATA\x10\x03*4\n\x13MetricQueryFunction\x12\x08\n\x04RATE\x10\x00\x12\t\n\x05\x43OUNT\x10\x01\x12\x08\n\x04NONE\x10\x02*\x9b\x01\n\x10RollupAggregator\x12\x19\n\x15ROLLUP_AGGREGATOR_SUM\x10\x00\x12\x1b\n\x17ROLLUP_AGGREGATOR_COUNT\x10\x01\x12\x19\n\x15ROLLUP_AGGREGATOR_MIN\x10\x02\x12\x19\n\x15ROLLUP_AGGREGATOR_MAX\x10\x03\x12\x19\n\x15ROLLUP_AGGREGATOR_AVG\x10\x04*A\n\x1bMetricQuerySpaceAggregation\x12\x07\n\x03\x41VG\x10\x00\x12\x07\n\x03MIN\x10\x01\x12\x07\n\x03MAX\x10\x02\x12\x07\n\x03SUM\x10\x03\x32\xeb\x06\n\rObservability\x12\xf7\x01\n\x16QueryTimeSeriesMetrics\x12:.tigrisdata.observability.v1.QueryTimeSeriesMetricsRequest\x1a;.tigrisdata.observability.v1.QueryTimeSeriesMetricsResponse\"d\x82\xd3\xe4\x93\x02/\"*/v1/observability/metrics/timeseries/query:\x01*\xbaG,\n\rObservability\x12\x1bQueries time series metrics\x12\xd5\x01\n\x0bQuotaLimits\x12/.tigrisdata.observability.v1.QuotaLimitsRequest\x1a\x30.tigrisdata.observability.v1.QuotaLimitsResponse\"c\x82\xd3\xe4\x93\x02#\"\x1e/v1/observability/quota/limits:\x01*\xbaG7\n\rObservability\x12&Queries current namespace quota limits\x12\xd0\x01\n\nQuotaUsage\x12..tigrisdata.observability.v1.QuotaUsageRequest\x1a/.tigrisdata.observability.v1.QuotaUsageResponse\"a\x82\xd3\xe4\x93\x02\"\"\x1d/v1/observability/quota/usage:\x01*\xbaG6\n\rObservability\x12%Queries current namespace quota usage\x12\xb4\x01\n\x07GetInfo\x12+.tigrisdata.observability.v1.GetInfoRequest\x1a,.tigrisdata.observability.v1.GetInfoResponse\"N\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/observability/info\xbaG-\n\rObservability\x12\x1cInformation about the serverBA\n\x1d\x63om.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/apib\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'server.v1.observability_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/api'
  _OBSERVABILITY.methods_by_name['QueryTimeSeriesMetrics']._options = None
  _OBSERVABILITY.methods_by_name['QueryTimeSeriesMetrics']._serialized_options = b'\202\323\344\223\002/\"*/v1/observability/metrics/timeseries/query:\001*\272G,\n\rObservability\022\033Queries time series metrics'
  _OBSERVABILITY.methods_by_name['QuotaLimits']._options = None
  _OBSERVABILITY.methods_by_name['QuotaLimits']._serialized_options = b'\202\323\344\223\002#\"\036/v1/observability/quota/limits:\001*\272G7\n\rObservability\022&Queries current namespace quota limits'
  _OBSERVABILITY.methods_by_name['QuotaUsage']._options = None
  _OBSERVABILITY.methods_by_name['QuotaUsage']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/observability/quota/usage:\001*\272G6\n\rObservability\022%Queries current namespace quota usage'
  _OBSERVABILITY.methods_by_name['GetInfo']._options = None
  _OBSERVABILITY.methods_by_name['GetInfo']._serialized_options = b'\202\323\344\223\002\030\022\026/v1/observability/info\272G-\n\rObservability\022\034Information about the server'
  _CODE._serialized_start=1732
  _CODE._serialized_end=2121
  _TIGRISOPERATION._serialized_start=2123
  _TIGRISOPERATION._serialized_end=2184
  _METRICQUERYFUNCTION._serialized_start=2186
  _METRICQUERYFUNCTION._serialized_end=2238
  _ROLLUPAGGREGATOR._serialized_start=2241
  _ROLLUPAGGREGATOR._serialized_end=2396
  _METRICQUERYSPACEAGGREGATION._serialized_start=2398
  _METRICQUERYSPACEAGGREGATION._serialized_end=2463
  _RETRYINFO._serialized_start=121
  _RETRYINFO._serialized_end=147
  _ERRORDETAILS._serialized_start=149
  _ERRORDETAILS._serialized_end=249
  _ERROR._serialized_start=251
  _ERROR._serialized_end=324
  _QUERYTIMESERIESMETRICSREQUEST._serialized_start=327
  _QUERYTIMESERIESMETRICSREQUEST._serialized_end=803
  _ADDITIONALFUNCTION._serialized_start=805
  _ADDITIONALFUNCTION._serialized_end=902
  _ROLLUPFUNCTION._serialized_start=904
  _ROLLUPFUNCTION._serialized_end=1005
  _QUERYTIMESERIESMETRICSRESPONSE._serialized_start=1008
  _QUERYTIMESERIESMETRICSRESPONSE._serialized_end=1140
  _METRICSERIES._serialized_start=1143
  _METRICSERIES._serialized_end=1274
  _DATAPOINT._serialized_start=1276
  _DATAPOINT._serialized_end=1321
  _QUOTALIMITSREQUEST._serialized_start=1323
  _QUOTALIMITSREQUEST._serialized_end=1343
  _QUOTALIMITSRESPONSE._serialized_start=1345
  _QUOTALIMITSRESPONSE._serialized_end=1426
  _QUOTAUSAGEREQUEST._serialized_start=1428
  _QUOTAUSAGEREQUEST._serialized_end=1447
  _QUOTAUSAGERESPONSE._serialized_start=1450
  _QUOTAUSAGERESPONSE._serialized_end=1617
  _GETINFOREQUEST._serialized_start=1619
  _GETINFOREQUEST._serialized_end=1635
  _GETINFORESPONSE._serialized_start=1637
  _GETINFORESPONSE._serialized_end=1729
  _OBSERVABILITY._serialized_start=2466
  _OBSERVABILITY._serialized_end=3341
# @@protoc_insertion_point(module_scope)
