# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: server/v1/api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from ...openapiv3 import annotations_pb2 as openapiv3_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13server/v1/api.proto\x12\rtigrisdata.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bopenapiv3/annotations.proto\"\x0e\n\x0cWriteOptions\"\x19\n\tCollation\x12\x0c\n\x04\x63\x61se\x18\x01 \x01(\t\"n\n\x12ReadRequestOptions\x12\r\n\x05limit\x18\x02 \x01(\x03\x12\x0c\n\x04skip\x18\x03 \x01(\x03\x12\x0e\n\x06offset\x18\x04 \x01(\x0c\x12+\n\tcollation\x18\x05 \x01(\x0b\x32\x18.tigrisdata.v1.Collation\"\x11\n\x0f\x44\x61tabaseOptions\"\x13\n\x11\x43ollectionOptions\"\x14\n\x12TransactionOptions\",\n\x0eTransactionCtx\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06origin\x18\x02 \x01(\t\"n\n\x17\x42\x65ginTransactionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x32\n\x07options\x18\x02 \x01(\x0b\x32!.tigrisdata.v1.TransactionOptions\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\"I\n\x18\x42\x65ginTransactionResponse\x12-\n\x06tx_ctx\x18\x01 \x01(\x0b\x32\x1d.tigrisdata.v1.TransactionCtx\";\n\x18\x43ommitTransactionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\"+\n\x19\x43ommitTransactionResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"=\n\x1aRollbackTransactionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\"-\n\x1bRollbackTransactionResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\"J\n\x14InsertRequestOptions\x12\x32\n\rwrite_options\x18\x01 \x01(\x0b\x32\x1b.tigrisdata.v1.WriteOptions\"J\n\x14ImportRequestOptions\x12\x32\n\rwrite_options\x18\x01 \x01(\x0b\x32\x1b.tigrisdata.v1.WriteOptions\"\xa2\x01\n\x10ResponseMetadata\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8d\x01\n\rInsertRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x11\n\tdocuments\x18\x03 \x03(\x0c\x12\x34\n\x07options\x18\x04 \x01(\x0b\x32#.tigrisdata.v1.InsertRequestOptions\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\"a\n\x0eInsertResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\x0c\"\xd4\x01\n\rImportRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x11\n\tdocuments\x18\x03 \x03(\x0c\x12\x34\n\x07options\x18\x04 \x01(\x0b\x32#.tigrisdata.v1.ImportRequestOptions\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\x12\x19\n\x11\x63reate_collection\x18\x06 \x01(\x08\x12\x13\n\x0bprimary_key\x18\x07 \x03(\t\x12\x15\n\rautogenerated\x18\x08 \x03(\t\"a\n\x0eImportResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\x0c\"K\n\x15ReplaceRequestOptions\x12\x32\n\rwrite_options\x18\x01 \x01(\x0b\x32\x1b.tigrisdata.v1.WriteOptions\"\x8f\x01\n\x0eReplaceRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x11\n\tdocuments\x18\x03 \x03(\x0c\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.tigrisdata.v1.ReplaceRequestOptions\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\"b\n\x0fReplaceResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x0c\n\x04keys\x18\x03 \x03(\x0c\"\x86\x01\n\x14\x44\x65leteRequestOptions\x12\x32\n\rwrite_options\x18\x01 \x01(\x0b\x32\x1b.tigrisdata.v1.WriteOptions\x12+\n\tcollation\x18\x02 \x01(\x0b\x32\x18.tigrisdata.v1.Collation\x12\r\n\x05limit\x18\x03 \x01(\x03\"\x8a\x01\n\rDeleteRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\x0c\x12\x34\n\x07options\x18\x04 \x01(\x0b\x32#.tigrisdata.v1.DeleteRequestOptions\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\"j\n\x0e\x44\x65leteResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x15\n\rdeleted_count\x18\x03 \x01(\x05\"\x86\x01\n\x14UpdateRequestOptions\x12\x32\n\rwrite_options\x18\x01 \x01(\x0b\x32\x1b.tigrisdata.v1.WriteOptions\x12+\n\tcollation\x18\x02 \x01(\x0b\x32\x18.tigrisdata.v1.Collation\x12\r\n\x05limit\x18\x03 \x01(\x03\"\x9a\x01\n\rUpdateRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06\x66ields\x18\x03 \x01(\x0c\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\x0c\x12\x34\n\x07options\x18\x05 \x01(\x0b\x32#.tigrisdata.v1.UpdateRequestOptions\x12\x0e\n\x06\x62ranch\x18\x06 \x01(\t\"k\n\x0eUpdateResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\x12\x16\n\x0emodified_count\x18\x02 \x01(\x05\x12\x0e\n\x06status\x18\x03 \x01(\t\"\xa4\x01\n\x0bReadRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\x0c\x12\x0e\n\x06\x66ields\x18\x04 \x01(\x0c\x12\x32\n\x07options\x18\x05 \x01(\x0b\x32!.tigrisdata.v1.ReadRequestOptions\x12\x0c\n\x04sort\x18\x06 \x01(\x0c\x12\x0e\n\x06\x62ranch\x18\x07 \x01(\t\"e\n\x0cReadResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x14\n\x0cresume_token\x18\x02 \x01(\x0c\x12\x31\n\x08metadata\x18\x03 \x01(\x0b\x32\x1f.tigrisdata.v1.ResponseMetadata\"S\n\x0c\x43ountRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\x0c\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\"\x1e\n\rCountResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\"{\n\x0f\x45xplainResponse\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x11\n\tread_type\x18\x02 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x0f\n\x07sorting\x18\x04 \x01(\t\x12\x11\n\tkey_range\x18\x05 \x03(\t\x12\r\n\x05\x66ield\x18\x06 \x01(\t\"\xb3\x02\n\rSearchRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\t\n\x01q\x18\x03 \x01(\t\x12\x15\n\rsearch_fields\x18\x04 \x03(\t\x12\x0e\n\x06\x66ilter\x18\x05 \x01(\x0c\x12\r\n\x05\x66\x61\x63\x65t\x18\x06 \x01(\x0c\x12\x0c\n\x04sort\x18\x07 \x01(\x0c\x12\x16\n\x0einclude_fields\x18\x08 \x03(\t\x12\x16\n\x0e\x65xclude_fields\x18\t \x03(\t\x12\x11\n\tpage_size\x18\n \x01(\x05\x12\x0c\n\x04page\x18\x0b \x01(\x05\x12+\n\tcollation\x18\x0c \x01(\x0b\x32\x18.tigrisdata.v1.Collation\x12\x0e\n\x06\x62ranch\x18\r \x01(\t\x12\x10\n\x08group_by\x18\x0e \x01(\x0c\x12\x0e\n\x06vector\x18\x0f \x01(\x0c\"\x9c\x02\n\x0eSearchResponse\x12&\n\x04hits\x18\x01 \x03(\x0b\x32\x18.tigrisdata.v1.SearchHit\x12\x39\n\x06\x66\x61\x63\x65ts\x18\x02 \x03(\x0b\x32).tigrisdata.v1.SearchResponse.FacetsEntry\x12+\n\x04meta\x18\x03 \x01(\x0b\x32\x1d.tigrisdata.v1.SearchMetadata\x12/\n\x05group\x18\x04 \x03(\x0b\x32 .tigrisdata.v1.GroupedSearchHits\x1aI\n\x0b\x46\x61\x63\x65tsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.tigrisdata.v1.SearchFacet:\x02\x38\x01\"I\n\tSearchHit\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12.\n\x08metadata\x18\x02 \x01(\x0b\x32\x1c.tigrisdata.v1.SearchHitMeta\"\x94\x01\n\rSearchHitMeta\x12.\n\ncreated_at\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x05match\x18\x03 \x01(\x0b\x32\x14.tigrisdata.v1.Match\"b\n\x0bSearchFacet\x12)\n\x06\x63ounts\x18\x01 \x03(\x0b\x32\x19.tigrisdata.v1.FacetCount\x12(\n\x05stats\x18\x02 \x01(\x0b\x32\x19.tigrisdata.v1.FacetStats\"*\n\nFacetCount\x12\r\n\x05\x63ount\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t\"\x83\x01\n\nFacetStats\x12\x10\n\x03\x61vg\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x10\n\x03max\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x10\n\x03min\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x10\n\x03sum\x18\x04 \x01(\x01H\x03\x88\x01\x01\x12\r\n\x05\x63ount\x18\x05 \x01(\x03\x42\x06\n\x04_avgB\x06\n\x04_maxB\x06\n\x04_minB\x06\n\x04_sum\"o\n\x0eSearchMetadata\x12\r\n\x05\x66ound\x18\x01 \x01(\x03\x12\x13\n\x0btotal_pages\x18\x02 \x01(\x05\x12!\n\x04page\x18\x03 \x01(\x0b\x32\x13.tigrisdata.v1.Page\x12\x16\n\x0ematched_fields\x18\x04 \x03(\t\"\x1a\n\nMatchField\x12\x0c\n\x04name\x18\x01 \x01(\t\"s\n\x05Match\x12)\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x19.tigrisdata.v1.MatchField\x12\r\n\x05score\x18\x02 \x01(\t\x12\x1c\n\x0fvector_distance\x18\x03 \x01(\x01H\x00\x88\x01\x01\x42\x12\n\x10_vector_distance\"O\n\x11GroupedSearchHits\x12\x12\n\ngroup_keys\x18\x01 \x03(\t\x12&\n\x04hits\x18\x02 \x03(\x0b\x32\x18.tigrisdata.v1.SearchHit\"%\n\x04Page\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x05\x12\x0c\n\x04size\x18\x03 \x01(\x05\"\'\n\x14\x43reateProjectRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\"8\n\x15\x43reateProjectResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\'\n\x14\x44\x65leteProjectRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\"8\n\x15\x44\x65leteProjectResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"6\n\x13\x43reateBranchRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\"7\n\x14\x43reateBranchResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"6\n\x13\x44\x65leteBranchRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x02 \x01(\t\"7\n\x14\x44\x65leteBranchResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"&\n\x13ListBranchesRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\"C\n\x14ListBranchesResponse\x12+\n\x08\x62ranches\x18\x01 \x03(\x0b\x32\x19.tigrisdata.v1.BranchInfo\"\xae\x01\n\x1f\x43reateOrUpdateCollectionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\x0c\x12\x13\n\x0bonly_create\x18\x04 \x01(\x08\x12\x31\n\x07options\x18\x05 \x01(\x0b\x32 .tigrisdata.v1.CollectionOptions\x12\x0e\n\x06\x62ranch\x18\x06 \x01(\t\"C\n CreateOrUpdateCollectionResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"\x7f\n\x15\x44ropCollectionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32 .tigrisdata.v1.CollectionOptions\x12\x0e\n\x06\x62ranch\x18\x04 \x01(\t\"9\n\x16\x44ropCollectionResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"P\n\x0bProjectInfo\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x30\n\x08metadata\x18\x02 \x01(\x0b\x32\x1e.tigrisdata.v1.ProjectMetadata\"Y\n\x0e\x43ollectionInfo\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32!.tigrisdata.v1.CollectionMetadata\"M\n\nBranchInfo\x12\x0e\n\x06\x62ranch\x18\x01 \x01(\t\x12/\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.tigrisdata.v1.BranchMetadata\"\x15\n\x13ListProjectsRequest\"D\n\x14ListProjectsResponse\x12,\n\x08projects\x18\x01 \x03(\x0b\x32\x1a.tigrisdata.v1.ProjectInfo\"l\n\x16ListCollectionsRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x31\n\x07options\x18\x02 \x01(\x0b\x32 .tigrisdata.v1.CollectionOptions\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\"M\n\x17ListCollectionsResponse\x12\x32\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32\x1d.tigrisdata.v1.CollectionInfo\"Q\n\x17\x44\x65scribeDatabaseRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x15\n\rschema_format\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\"\x9a\x01\n\x19\x44\x65scribeCollectionRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x15\n\rschema_format\x18\x03 \x01(\t\x12\x31\n\x07options\x18\x04 \x01(\x0b\x32 .tigrisdata.v1.CollectionOptions\x12\x0e\n\x06\x62ranch\x18\x05 \x01(\t\"\xa8\x01\n\x18\x44\x65scribeDatabaseResponse\x12\x31\n\x08metadata\x18\x01 \x01(\x0b\x32\x1f.tigrisdata.v1.DatabaseMetadata\x12\x39\n\x0b\x63ollections\x18\x02 \x03(\x0b\x32$.tigrisdata.v1.CollectionDescription\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x10\n\x08\x62ranches\x18\x04 \x03(\t\"\xb4\x01\n\x1a\x44\x65scribeCollectionResponse\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32!.tigrisdata.v1.CollectionMetadata\x12\x0e\n\x06schema\x18\x03 \x01(\x0c\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12/\n\x07indexes\x18\x05 \x03(\x0b\x32\x1e.tigrisdata.v1.CollectionIndex\"\x14\n\x12ProjectDescription\"\xaf\x01\n\x15\x43ollectionDescription\x12\x12\n\ncollection\x18\x01 \x01(\t\x12\x33\n\x08metadata\x18\x02 \x01(\x0b\x32!.tigrisdata.v1.CollectionMetadata\x12\x0e\n\x06schema\x18\x03 \x01(\x0c\x12\x0c\n\x04size\x18\x04 \x01(\x03\x12/\n\x07indexes\x18\x05 \x03(\x0b\x32\x1e.tigrisdata.v1.CollectionIndex\"\x11\n\x0fProjectMetadata\"\x12\n\x10\x44\x61tabaseMetadata\"\x14\n\x12\x43ollectionMetadata\"T\n\x0f\x43ollectionIndex\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05state\x18\x02 \x01(\t\x12$\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x14.tigrisdata.v1.Field\"\x15\n\x05\x46ield\x12\x0c\n\x04name\x18\x01 \x01(\t\"R\n\x1b\x42uildCollectionIndexRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x12\n\ncollection\x18\x02 \x01(\t\x12\x0e\n\x06\x62ranch\x18\x03 \x01(\t\"O\n\x1c\x42uildCollectionIndexResponse\x12/\n\x07indexes\x18\x01 \x03(\x0b\x32\x1e.tigrisdata.v1.CollectionIndex\"\x10\n\x0e\x42ranchMetadata\"I\n\x13\x43reateAppKeyRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"F\n\x14\x43reateAppKeyResponse\x12.\n\x0f\x63reated_app_key\x18\x01 \x01(\x0b\x32\x15.tigrisdata.v1.AppKey\"U\n\x13UpdateAppKeyRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"F\n\x14UpdateAppKeyResponse\x12.\n\x0fupdated_app_key\x18\x01 \x01(\x0b\x32\x15.tigrisdata.v1.AppKey\"\xa8\x01\n\x06\x41ppKey\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06secret\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\x03\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\"%\n\x12ListAppKeysRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\">\n\x13ListAppKeysResponse\x12\'\n\x08\x61pp_keys\x18\x01 \x03(\x0b\x32\x15.tigrisdata.v1.AppKey\"2\n\x13\x44\x65leteAppKeyRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\"\'\n\x14\x44\x65leteAppKeyResponse\x12\x0f\n\x07\x64\x65leted\x18\x01 \x01(\x08\"2\n\x13RotateAppKeyRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07project\x18\x02 \x01(\t\">\n\x14RotateAppKeyResponse\x12&\n\x07\x61pp_key\x18\x01 \x01(\x0b\x32\x15.tigrisdata.v1.AppKey2\xba,\n\x06Tigris\x12\xc4\x01\n\x10\x42\x65ginTransaction\x12&.tigrisdata.v1.BeginTransactionRequest\x1a\'.tigrisdata.v1.BeginTransactionResponse\"_\x82\xd3\xe4\x93\x02\x37\"2/v1/projects/{project}/database/transactions/begin:\x01*\xbaG\x1f\n\x08\x44\x61tabase\x12\x13\x42\x65gin a transaction\x12\xc9\x01\n\x11\x43ommitTransaction\x12\'.tigrisdata.v1.CommitTransactionRequest\x1a(.tigrisdata.v1.CommitTransactionResponse\"a\x82\xd3\xe4\x93\x02\x38\"3/v1/projects/{project}/database/transactions/commit:\x01*\xbaG \n\x08\x44\x61tabase\x12\x14\x43ommit a Transaction\x12\xd3\x01\n\x13RollbackTransaction\x12).tigrisdata.v1.RollbackTransactionRequest\x1a*.tigrisdata.v1.RollbackTransactionResponse\"e\x82\xd3\xe4\x93\x02:\"5/v1/projects/{project}/database/transactions/rollback:\x01*\xbaG\"\n\x08\x44\x61tabase\x12\x16Rollback a transaction\x12\xbd\x01\n\x06Insert\x12\x1c.tigrisdata.v1.InsertRequest\x1a\x1d.tigrisdata.v1.InsertResponse\"v\x82\xd3\xe4\x93\x02N\"I/v1/projects/{project}/database/collections/{collection}/documents/insert:\x01*\xbaG\x1f\n\x0b\x43ollections\x12\x10Insert Documents\x12\xcd\x01\n\x07Replace\x12\x1d.tigrisdata.v1.ReplaceRequest\x1a\x1e.tigrisdata.v1.ReplaceResponse\"\x82\x01\x82\xd3\xe4\x93\x02O\x1aJ/v1/projects/{project}/database/collections/{collection}/documents/replace:\x01*\xbaG*\n\x0b\x43ollections\x12\x1bInsert or Replace Documents\x12\xbd\x01\n\x06\x44\x65lete\x12\x1c.tigrisdata.v1.DeleteRequest\x1a\x1d.tigrisdata.v1.DeleteResponse\"v\x82\xd3\xe4\x93\x02N*I/v1/projects/{project}/database/collections/{collection}/documents/delete:\x01*\xbaG\x1f\n\x0b\x43ollections\x12\x10\x44\x65lete Documents\x12\xbe\x01\n\x06Update\x12\x1c.tigrisdata.v1.UpdateRequest\x1a\x1d.tigrisdata.v1.UpdateResponse\"w\x82\xd3\xe4\x93\x02N\x1aI/v1/projects/{project}/database/collections/{collection}/documents/update:\x01*\xbaG \n\x0b\x43ollections\x12\x11Update Documents.\x12\xb5\x01\n\x04Read\x12\x1a.tigrisdata.v1.ReadRequest\x1a\x1b.tigrisdata.v1.ReadResponse\"r\x82\xd3\xe4\x93\x02L\"G/v1/projects/{project}/database/collections/{collection}/documents/read:\x01*\xbaG\x1d\n\x0b\x43ollections\x12\x0eRead Documents0\x01\x12\xb8\x01\n\x05\x43ount\x12\x1b.tigrisdata.v1.CountRequest\x1a\x1c.tigrisdata.v1.CountResponse\"t\x82\xd3\xe4\x93\x02M\"H/v1/projects/{project}/database/collections/{collection}/documents/count:\x01*\xbaG\x1e\n\x0b\x43ollections\x12\x0f\x43ount Documents\x12\xfc\x01\n\x14\x42uildCollectionIndex\x12*.tigrisdata.v1.BuildCollectionIndexRequest\x1a+.tigrisdata.v1.BuildCollectionIndexResponse\"\x8a\x01\x82\xd3\xe4\x93\x02M\"H/v1/projects/{project}/database/collections/{collection}/documents/index:\x01*\xbaG4\n\x0b\x43ollections\x12%Index all documents in the collection\x12\xc4\x01\n\x07\x45xplain\x12\x1a.tigrisdata.v1.ReadRequest\x1a\x1e.tigrisdata.v1.ExplainResponse\"}\x82\xd3\xe4\x93\x02O\"J/v1/projects/{project}/database/collections/{collection}/documents/explain:\x01*\xbaG%\n\x0b\x43ollections\x12\x16\x45xplain Read Documents\x12\xc0\x01\n\x06Search\x12\x1c.tigrisdata.v1.SearchRequest\x1a\x1d.tigrisdata.v1.SearchResponse\"w\x82\xd3\xe4\x93\x02N\"I/v1/projects/{project}/database/collections/{collection}/documents/search:\x01*\xbaG \n\x0b\x43ollections\x12\x11Search Documents.0\x01\x12\xbd\x01\n\x06Import\x12\x1c.tigrisdata.v1.ImportRequest\x1a\x1d.tigrisdata.v1.ImportResponse\"v\x82\xd3\xe4\x93\x02N\"I/v1/projects/{project}/database/collections/{collection}/documents/import:\x01*\xbaG\x1f\n\x0b\x43ollections\x12\x10Import Documents\x12\xff\x01\n\x18\x43reateOrUpdateCollection\x12..tigrisdata.v1.CreateOrUpdateCollectionRequest\x1a/.tigrisdata.v1.CreateOrUpdateCollectionResponse\"\x81\x01\x82\xd3\xe4\x93\x02L\"G/v1/projects/{project}/database/collections/{collection}/createOrUpdate:\x01*\xbaG,\n\x0b\x43ollections\x12\x1d\x43reate or update a collection\x12\xc8\x01\n\x0e\x44ropCollection\x12$.tigrisdata.v1.DropCollectionRequest\x1a%.tigrisdata.v1.DropCollectionResponse\"i\x82\xd3\xe4\x93\x02\x42*=/v1/projects/{project}/database/collections/{collection}/drop:\x01*\xbaG\x1e\n\x0b\x43ollections\x12\x0f\x44rop Collection\x12\x89\x01\n\x0cListProjects\x12\".tigrisdata.v1.ListProjectsRequest\x1a#.tigrisdata.v1.ListProjectsResponse\"0\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/projects\xbaG\x19\n\x08Projects\x12\rList Projects\x12\xb4\x01\n\x0fListCollections\x12%.tigrisdata.v1.ListCollectionsRequest\x1a&.tigrisdata.v1.ListCollectionsResponse\"R\x82\xd3\xe4\x93\x02-\x12+/v1/projects/{project}/database/collections\xbaG\x1c\n\x08\x44\x61tabase\x12\x10List Collections\x12\xa1\x01\n\rCreateProject\x12#.tigrisdata.v1.CreateProjectRequest\x1a$.tigrisdata.v1.CreateProjectResponse\"E\x82\xd3\xe4\x93\x02\"\"\x1d/v1/projects/{project}/create:\x01*\xbaG\x1a\n\x08Projects\x12\x0e\x43reate Project\x12\xc1\x01\n\rDeleteProject\x12#.tigrisdata.v1.DeleteProjectRequest\x1a$.tigrisdata.v1.DeleteProjectResponse\"e\x82\xd3\xe4\x93\x02\"*\x1d/v1/projects/{project}/delete:\x01*\xbaG:\n\x08Projects\x12.Delete Project and all resources under project\x12\xb8\x01\n\x10\x44\x65scribeDatabase\x12&.tigrisdata.v1.DescribeDatabaseRequest\x1a\'.tigrisdata.v1.DescribeDatabaseResponse\"S\x82\xd3\xe4\x93\x02-\"(/v1/projects/{project}/database/describe:\x01*\xbaG\x1d\n\x08\x44\x61tabase\x12\x11\x44\x65scribe database\x12\xc3\x01\n\x0c\x43reateBranch\x12\".tigrisdata.v1.CreateBranchRequest\x1a#.tigrisdata.v1.CreateBranchResponse\"j\x82\xd3\xe4\x93\x02=\"8/v1/projects/{project}/database/branches/{branch}/create:\x01*\xbaG$\n\x08\x44\x61tabase\x12\x18\x43reate a database branch\x12\xc3\x01\n\x0c\x44\x65leteBranch\x12\".tigrisdata.v1.DeleteBranchRequest\x1a#.tigrisdata.v1.DeleteBranchResponse\"j\x82\xd3\xe4\x93\x02=*8/v1/projects/{project}/database/branches/{branch}/delete:\x01*\xbaG$\n\x08\x44\x61tabase\x12\x18\x44\x65lete a database branch\x12\xae\x01\n\x0cListBranches\x12\".tigrisdata.v1.ListBranchesRequest\x1a#.tigrisdata.v1.ListBranchesResponse\"U\x82\xd3\xe4\x93\x02*\x12(/v1/projects/{project}/database/branches\xbaG\"\n\x08\x44\x61tabase\x12\x16List database branches\x12\xdc\x01\n\x12\x44\x65scribeCollection\x12(.tigrisdata.v1.DescribeCollectionRequest\x1a).tigrisdata.v1.DescribeCollectionResponse\"q\x82\xd3\xe4\x93\x02\x46\"A/v1/projects/{project}/database/collections/{collection}/describe:\x01*\xbaG\"\n\x0b\x43ollections\x12\x13\x44\x65scribe Collection\x12\xb5\x01\n\x0c\x43reateAppKey\x12\".tigrisdata.v1.CreateAppKeyRequest\x1a#.tigrisdata.v1.CreateAppKeyResponse\"\\\x82\xd3\xe4\x93\x02,\"\'/v1/projects/{project}/apps/keys/create:\x01*\xbaG\'\n\x10\x41pplication Keys\x12\x13\x43reates the app key\x12\xc8\x01\n\x0cUpdateAppKey\x12\".tigrisdata.v1.UpdateAppKeyRequest\x1a#.tigrisdata.v1.UpdateAppKeyResponse\"o\x82\xd3\xe4\x93\x02,\"\'/v1/projects/{project}/apps/keys/update:\x01*\xbaG:\n\x10\x41pplication Keys\x12&Updates the description of the app key\x12\xb5\x01\n\x0c\x44\x65leteAppKey\x12\".tigrisdata.v1.DeleteAppKeyRequest\x1a#.tigrisdata.v1.DeleteAppKeyResponse\"\\\x82\xd3\xe4\x93\x02,*\'/v1/projects/{project}/apps/keys/delete:\x01*\xbaG\'\n\x10\x41pplication Keys\x12\x13\x44\x65letes the app key\x12\xaa\x01\n\x0bListAppKeys\x12!.tigrisdata.v1.ListAppKeysRequest\x1a\".tigrisdata.v1.ListAppKeysResponse\"T\x82\xd3\xe4\x93\x02\"\x12 /v1/projects/{project}/apps/keys\xbaG)\n\x10\x41pplication Keys\x12\x15List all the app keys\x12\xc2\x01\n\x12RotateAppKeySecret\x12\".tigrisdata.v1.RotateAppKeyRequest\x1a#.tigrisdata.v1.RotateAppKeyResponse\"c\x82\xd3\xe4\x93\x02,\"\'/v1/projects/{project}/apps/keys/rotate:\x01*\xbaG.\n\x10\x41pplication Keys\x12\x1aRotates the app key secretB\x80\x13\n\x1d\x63om.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/api\xbaG\xbb\x12\x12\x96\x02\n\x14Tigris API Reference\x12\xac\x01\n## Overview\nThis section is organized around HTTP APIs. The APIs accepts JSON requests and returns JSON-encoded responses. The APIs conforms to standard HTTP status codes.*H\n\x0e\x41pache License\x12\x36https://github.com/tigrisdata/tigris/blob/main/LICENSE2\x05\x30.0.1\x1a\x34\n$https://api.preview.tigrisdata.cloud\x12\x0cTigris Cloud\x1a\"\n\x15http://localhost:8081\x12\tLocalhost*\": \n\x1e\n\nBearerAuth\x12\x10\n\x0e\n\x04http*\x06\x62\x65\x61rer2\x10\n\x0e\n\nBearerAuth\x12\x00:\x99\x03\n\x0e\x41uthentication\x12\x86\x03The auth section of API provides OAuth 2.0 APIs. Tigris supports pluggable OAuth provider. Pass the token in the headers for authentication, as an example `-H \"Authorization: Bearer eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6I\"`(replace it with your token). All API requests must be made over HTTPS. Calls made over plain HTTP will fail. API requests without authentication will also fail.:\xb4\x01\n\x10\x41pplication Keys\x12\x9f\x01The application keys section provide APIs that can be used to manage application keys for your project. A single project can have one or more application keys.:\x82\x02\n\x08Projects\x12\xf5\x01\x45very Tigris projects comes with a transactional document database built on FoundationDB, one of the most resilient and battle-tested open source distributed key-value store. A database is created automatically for you when you create a project.:\xd9\x01\n\x08\x44\x61tabase\x12\xcc\x01The Database section provide APIs that can be used to interact with the database. A single Database can have one or more collections. A database is created automatically for you when you create a project.:\x88\x01\n\x0b\x43ollections\x12yThe Collections section provide APIs that can be used to manage collections. A collection can have one or more documents.:a\n\nManagement\x12SThe Management section provide APIs that can be used to manage users, and app_keys.:\x89\x01\n\rObservability\x12xThe Observability section has APIs that provides full visibility into the health, metrics, and monitoring of the Server.:U\n\x05\x43\x61\x63he\x12LThe cache section provide APIs that can be used to perform cache operations.:S\n\x08Realtime\x12GThe realtime section provide APIs that can be used realtime operations.:\xd4\x01\n\x06Search\x12\xc9\x01The search section provides you APIs that can be used to implement powerful apps with search experiences. You can manage storing documents on your own or you can simply integrate it with your database.:_\n\x07\x42illing\x12TThe billing section provides APIs for managing invoices and payments infrastructure.b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'server.v1.api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.tigrisdata.db.api.v1.grpcZ github.com/tigrisdata/tigris/api\272G\273\022\022\226\002\n\024Tigris API Reference\022\254\001\n## Overview\nThis section is organized around HTTP APIs. The APIs accepts JSON requests and returns JSON-encoded responses. The APIs conforms to standard HTTP status codes.*H\n\016Apache License\0226https://github.com/tigrisdata/tigris/blob/main/LICENSE2\0050.0.1\0324\n$https://api.preview.tigrisdata.cloud\022\014Tigris Cloud\032\"\n\025http://localhost:8081\022\tLocalhost*\": \n\036\n\nBearerAuth\022\020\n\016\n\004http*\006bearer2\020\n\016\n\nBearerAuth\022\000:\231\003\n\016Authentication\022\206\003The auth section of API provides OAuth 2.0 APIs. Tigris supports pluggable OAuth provider. Pass the token in the headers for authentication, as an example `-H \"Authorization: Bearer eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6I\"`(replace it with your token). All API requests must be made over HTTPS. Calls made over plain HTTP will fail. API requests without authentication will also fail.:\264\001\n\020Application Keys\022\237\001The application keys section provide APIs that can be used to manage application keys for your project. A single project can have one or more application keys.:\202\002\n\010Projects\022\365\001Every Tigris projects comes with a transactional document database built on FoundationDB, one of the most resilient and battle-tested open source distributed key-value store. A database is created automatically for you when you create a project.:\331\001\n\010Database\022\314\001The Database section provide APIs that can be used to interact with the database. A single Database can have one or more collections. A database is created automatically for you when you create a project.:\210\001\n\013Collections\022yThe Collections section provide APIs that can be used to manage collections. A collection can have one or more documents.:a\n\nManagement\022SThe Management section provide APIs that can be used to manage users, and app_keys.:\211\001\n\rObservability\022xThe Observability section has APIs that provides full visibility into the health, metrics, and monitoring of the Server.:U\n\005Cache\022LThe cache section provide APIs that can be used to perform cache operations.:S\n\010Realtime\022GThe realtime section provide APIs that can be used realtime operations.:\324\001\n\006Search\022\311\001The search section provides you APIs that can be used to implement powerful apps with search experiences. You can manage storing documents on your own or you can simply integrate it with your database.:_\n\007Billing\022TThe billing section provides APIs for managing invoices and payments infrastructure.'
  _SEARCHRESPONSE_FACETSENTRY._options = None
  _SEARCHRESPONSE_FACETSENTRY._serialized_options = b'8\001'
  _TIGRIS.methods_by_name['BeginTransaction']._options = None
  _TIGRIS.methods_by_name['BeginTransaction']._serialized_options = b'\202\323\344\223\0027\"2/v1/projects/{project}/database/transactions/begin:\001*\272G\037\n\010Database\022\023Begin a transaction'
  _TIGRIS.methods_by_name['CommitTransaction']._options = None
  _TIGRIS.methods_by_name['CommitTransaction']._serialized_options = b'\202\323\344\223\0028\"3/v1/projects/{project}/database/transactions/commit:\001*\272G \n\010Database\022\024Commit a Transaction'
  _TIGRIS.methods_by_name['RollbackTransaction']._options = None
  _TIGRIS.methods_by_name['RollbackTransaction']._serialized_options = b'\202\323\344\223\002:\"5/v1/projects/{project}/database/transactions/rollback:\001*\272G\"\n\010Database\022\026Rollback a transaction'
  _TIGRIS.methods_by_name['Insert']._options = None
  _TIGRIS.methods_by_name['Insert']._serialized_options = b'\202\323\344\223\002N\"I/v1/projects/{project}/database/collections/{collection}/documents/insert:\001*\272G\037\n\013Collections\022\020Insert Documents'
  _TIGRIS.methods_by_name['Replace']._options = None
  _TIGRIS.methods_by_name['Replace']._serialized_options = b'\202\323\344\223\002O\032J/v1/projects/{project}/database/collections/{collection}/documents/replace:\001*\272G*\n\013Collections\022\033Insert or Replace Documents'
  _TIGRIS.methods_by_name['Delete']._options = None
  _TIGRIS.methods_by_name['Delete']._serialized_options = b'\202\323\344\223\002N*I/v1/projects/{project}/database/collections/{collection}/documents/delete:\001*\272G\037\n\013Collections\022\020Delete Documents'
  _TIGRIS.methods_by_name['Update']._options = None
  _TIGRIS.methods_by_name['Update']._serialized_options = b'\202\323\344\223\002N\032I/v1/projects/{project}/database/collections/{collection}/documents/update:\001*\272G \n\013Collections\022\021Update Documents.'
  _TIGRIS.methods_by_name['Read']._options = None
  _TIGRIS.methods_by_name['Read']._serialized_options = b'\202\323\344\223\002L\"G/v1/projects/{project}/database/collections/{collection}/documents/read:\001*\272G\035\n\013Collections\022\016Read Documents'
  _TIGRIS.methods_by_name['Count']._options = None
  _TIGRIS.methods_by_name['Count']._serialized_options = b'\202\323\344\223\002M\"H/v1/projects/{project}/database/collections/{collection}/documents/count:\001*\272G\036\n\013Collections\022\017Count Documents'
  _TIGRIS.methods_by_name['BuildCollectionIndex']._options = None
  _TIGRIS.methods_by_name['BuildCollectionIndex']._serialized_options = b'\202\323\344\223\002M\"H/v1/projects/{project}/database/collections/{collection}/documents/index:\001*\272G4\n\013Collections\022%Index all documents in the collection'
  _TIGRIS.methods_by_name['Explain']._options = None
  _TIGRIS.methods_by_name['Explain']._serialized_options = b'\202\323\344\223\002O\"J/v1/projects/{project}/database/collections/{collection}/documents/explain:\001*\272G%\n\013Collections\022\026Explain Read Documents'
  _TIGRIS.methods_by_name['Search']._options = None
  _TIGRIS.methods_by_name['Search']._serialized_options = b'\202\323\344\223\002N\"I/v1/projects/{project}/database/collections/{collection}/documents/search:\001*\272G \n\013Collections\022\021Search Documents.'
  _TIGRIS.methods_by_name['Import']._options = None
  _TIGRIS.methods_by_name['Import']._serialized_options = b'\202\323\344\223\002N\"I/v1/projects/{project}/database/collections/{collection}/documents/import:\001*\272G\037\n\013Collections\022\020Import Documents'
  _TIGRIS.methods_by_name['CreateOrUpdateCollection']._options = None
  _TIGRIS.methods_by_name['CreateOrUpdateCollection']._serialized_options = b'\202\323\344\223\002L\"G/v1/projects/{project}/database/collections/{collection}/createOrUpdate:\001*\272G,\n\013Collections\022\035Create or update a collection'
  _TIGRIS.methods_by_name['DropCollection']._options = None
  _TIGRIS.methods_by_name['DropCollection']._serialized_options = b'\202\323\344\223\002B*=/v1/projects/{project}/database/collections/{collection}/drop:\001*\272G\036\n\013Collections\022\017Drop Collection'
  _TIGRIS.methods_by_name['ListProjects']._options = None
  _TIGRIS.methods_by_name['ListProjects']._serialized_options = b'\202\323\344\223\002\016\022\014/v1/projects\272G\031\n\010Projects\022\rList Projects'
  _TIGRIS.methods_by_name['ListCollections']._options = None
  _TIGRIS.methods_by_name['ListCollections']._serialized_options = b'\202\323\344\223\002-\022+/v1/projects/{project}/database/collections\272G\034\n\010Database\022\020List Collections'
  _TIGRIS.methods_by_name['CreateProject']._options = None
  _TIGRIS.methods_by_name['CreateProject']._serialized_options = b'\202\323\344\223\002\"\"\035/v1/projects/{project}/create:\001*\272G\032\n\010Projects\022\016Create Project'
  _TIGRIS.methods_by_name['DeleteProject']._options = None
  _TIGRIS.methods_by_name['DeleteProject']._serialized_options = b'\202\323\344\223\002\"*\035/v1/projects/{project}/delete:\001*\272G:\n\010Projects\022.Delete Project and all resources under project'
  _TIGRIS.methods_by_name['DescribeDatabase']._options = None
  _TIGRIS.methods_by_name['DescribeDatabase']._serialized_options = b'\202\323\344\223\002-\"(/v1/projects/{project}/database/describe:\001*\272G\035\n\010Database\022\021Describe database'
  _TIGRIS.methods_by_name['CreateBranch']._options = None
  _TIGRIS.methods_by_name['CreateBranch']._serialized_options = b'\202\323\344\223\002=\"8/v1/projects/{project}/database/branches/{branch}/create:\001*\272G$\n\010Database\022\030Create a database branch'
  _TIGRIS.methods_by_name['DeleteBranch']._options = None
  _TIGRIS.methods_by_name['DeleteBranch']._serialized_options = b'\202\323\344\223\002=*8/v1/projects/{project}/database/branches/{branch}/delete:\001*\272G$\n\010Database\022\030Delete a database branch'
  _TIGRIS.methods_by_name['ListBranches']._options = None
  _TIGRIS.methods_by_name['ListBranches']._serialized_options = b'\202\323\344\223\002*\022(/v1/projects/{project}/database/branches\272G\"\n\010Database\022\026List database branches'
  _TIGRIS.methods_by_name['DescribeCollection']._options = None
  _TIGRIS.methods_by_name['DescribeCollection']._serialized_options = b'\202\323\344\223\002F\"A/v1/projects/{project}/database/collections/{collection}/describe:\001*\272G\"\n\013Collections\022\023Describe Collection'
  _TIGRIS.methods_by_name['CreateAppKey']._options = None
  _TIGRIS.methods_by_name['CreateAppKey']._serialized_options = b'\202\323\344\223\002,\"\'/v1/projects/{project}/apps/keys/create:\001*\272G\'\n\020Application Keys\022\023Creates the app key'
  _TIGRIS.methods_by_name['UpdateAppKey']._options = None
  _TIGRIS.methods_by_name['UpdateAppKey']._serialized_options = b'\202\323\344\223\002,\"\'/v1/projects/{project}/apps/keys/update:\001*\272G:\n\020Application Keys\022&Updates the description of the app key'
  _TIGRIS.methods_by_name['DeleteAppKey']._options = None
  _TIGRIS.methods_by_name['DeleteAppKey']._serialized_options = b'\202\323\344\223\002,*\'/v1/projects/{project}/apps/keys/delete:\001*\272G\'\n\020Application Keys\022\023Deletes the app key'
  _TIGRIS.methods_by_name['ListAppKeys']._options = None
  _TIGRIS.methods_by_name['ListAppKeys']._serialized_options = b'\202\323\344\223\002\"\022 /v1/projects/{project}/apps/keys\272G)\n\020Application Keys\022\025List all the app keys'
  _TIGRIS.methods_by_name['RotateAppKeySecret']._options = None
  _TIGRIS.methods_by_name['RotateAppKeySecret']._serialized_options = b'\202\323\344\223\002,\"\'/v1/projects/{project}/apps/keys/rotate:\001*\272G.\n\020Application Keys\022\032Rotates the app key secret'
  _WRITEOPTIONS._serialized_start=130
  _WRITEOPTIONS._serialized_end=144
  _COLLATION._serialized_start=146
  _COLLATION._serialized_end=171
  _READREQUESTOPTIONS._serialized_start=173
  _READREQUESTOPTIONS._serialized_end=283
  _DATABASEOPTIONS._serialized_start=285
  _DATABASEOPTIONS._serialized_end=302
  _COLLECTIONOPTIONS._serialized_start=304
  _COLLECTIONOPTIONS._serialized_end=323
  _TRANSACTIONOPTIONS._serialized_start=325
  _TRANSACTIONOPTIONS._serialized_end=345
  _TRANSACTIONCTX._serialized_start=347
  _TRANSACTIONCTX._serialized_end=391
  _BEGINTRANSACTIONREQUEST._serialized_start=393
  _BEGINTRANSACTIONREQUEST._serialized_end=503
  _BEGINTRANSACTIONRESPONSE._serialized_start=505
  _BEGINTRANSACTIONRESPONSE._serialized_end=578
  _COMMITTRANSACTIONREQUEST._serialized_start=580
  _COMMITTRANSACTIONREQUEST._serialized_end=639
  _COMMITTRANSACTIONRESPONSE._serialized_start=641
  _COMMITTRANSACTIONRESPONSE._serialized_end=684
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=686
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=747
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=749
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=794
  _INSERTREQUESTOPTIONS._serialized_start=796
  _INSERTREQUESTOPTIONS._serialized_end=870
  _IMPORTREQUESTOPTIONS._serialized_start=872
  _IMPORTREQUESTOPTIONS._serialized_end=946
  _RESPONSEMETADATA._serialized_start=949
  _RESPONSEMETADATA._serialized_end=1111
  _INSERTREQUEST._serialized_start=1114
  _INSERTREQUEST._serialized_end=1255
  _INSERTRESPONSE._serialized_start=1257
  _INSERTRESPONSE._serialized_end=1354
  _IMPORTREQUEST._serialized_start=1357
  _IMPORTREQUEST._serialized_end=1569
  _IMPORTRESPONSE._serialized_start=1571
  _IMPORTRESPONSE._serialized_end=1668
  _REPLACEREQUESTOPTIONS._serialized_start=1670
  _REPLACEREQUESTOPTIONS._serialized_end=1745
  _REPLACEREQUEST._serialized_start=1748
  _REPLACEREQUEST._serialized_end=1891
  _REPLACERESPONSE._serialized_start=1893
  _REPLACERESPONSE._serialized_end=1991
  _DELETEREQUESTOPTIONS._serialized_start=1994
  _DELETEREQUESTOPTIONS._serialized_end=2128
  _DELETEREQUEST._serialized_start=2131
  _DELETEREQUEST._serialized_end=2269
  _DELETERESPONSE._serialized_start=2271
  _DELETERESPONSE._serialized_end=2377
  _UPDATEREQUESTOPTIONS._serialized_start=2380
  _UPDATEREQUESTOPTIONS._serialized_end=2514
  _UPDATEREQUEST._serialized_start=2517
  _UPDATEREQUEST._serialized_end=2671
  _UPDATERESPONSE._serialized_start=2673
  _UPDATERESPONSE._serialized_end=2780
  _READREQUEST._serialized_start=2783
  _READREQUEST._serialized_end=2947
  _READRESPONSE._serialized_start=2949
  _READRESPONSE._serialized_end=3050
  _COUNTREQUEST._serialized_start=3052
  _COUNTREQUEST._serialized_end=3135
  _COUNTRESPONSE._serialized_start=3137
  _COUNTRESPONSE._serialized_end=3167
  _EXPLAINRESPONSE._serialized_start=3169
  _EXPLAINRESPONSE._serialized_end=3292
  _SEARCHREQUEST._serialized_start=3295
  _SEARCHREQUEST._serialized_end=3602
  _SEARCHRESPONSE._serialized_start=3605
  _SEARCHRESPONSE._serialized_end=3889
  _SEARCHRESPONSE_FACETSENTRY._serialized_start=3816
  _SEARCHRESPONSE_FACETSENTRY._serialized_end=3889
  _SEARCHHIT._serialized_start=3891
  _SEARCHHIT._serialized_end=3964
  _SEARCHHITMETA._serialized_start=3967
  _SEARCHHITMETA._serialized_end=4115
  _SEARCHFACET._serialized_start=4117
  _SEARCHFACET._serialized_end=4215
  _FACETCOUNT._serialized_start=4217
  _FACETCOUNT._serialized_end=4259
  _FACETSTATS._serialized_start=4262
  _FACETSTATS._serialized_end=4393
  _SEARCHMETADATA._serialized_start=4395
  _SEARCHMETADATA._serialized_end=4506
  _MATCHFIELD._serialized_start=4508
  _MATCHFIELD._serialized_end=4534
  _MATCH._serialized_start=4536
  _MATCH._serialized_end=4651
  _GROUPEDSEARCHHITS._serialized_start=4653
  _GROUPEDSEARCHHITS._serialized_end=4732
  _PAGE._serialized_start=4734
  _PAGE._serialized_end=4771
  _CREATEPROJECTREQUEST._serialized_start=4773
  _CREATEPROJECTREQUEST._serialized_end=4812
  _CREATEPROJECTRESPONSE._serialized_start=4814
  _CREATEPROJECTRESPONSE._serialized_end=4870
  _DELETEPROJECTREQUEST._serialized_start=4872
  _DELETEPROJECTREQUEST._serialized_end=4911
  _DELETEPROJECTRESPONSE._serialized_start=4913
  _DELETEPROJECTRESPONSE._serialized_end=4969
  _CREATEBRANCHREQUEST._serialized_start=4971
  _CREATEBRANCHREQUEST._serialized_end=5025
  _CREATEBRANCHRESPONSE._serialized_start=5027
  _CREATEBRANCHRESPONSE._serialized_end=5082
  _DELETEBRANCHREQUEST._serialized_start=5084
  _DELETEBRANCHREQUEST._serialized_end=5138
  _DELETEBRANCHRESPONSE._serialized_start=5140
  _DELETEBRANCHRESPONSE._serialized_end=5195
  _LISTBRANCHESREQUEST._serialized_start=5197
  _LISTBRANCHESREQUEST._serialized_end=5235
  _LISTBRANCHESRESPONSE._serialized_start=5237
  _LISTBRANCHESRESPONSE._serialized_end=5304
  _CREATEORUPDATECOLLECTIONREQUEST._serialized_start=5307
  _CREATEORUPDATECOLLECTIONREQUEST._serialized_end=5481
  _CREATEORUPDATECOLLECTIONRESPONSE._serialized_start=5483
  _CREATEORUPDATECOLLECTIONRESPONSE._serialized_end=5550
  _DROPCOLLECTIONREQUEST._serialized_start=5552
  _DROPCOLLECTIONREQUEST._serialized_end=5679
  _DROPCOLLECTIONRESPONSE._serialized_start=5681
  _DROPCOLLECTIONRESPONSE._serialized_end=5738
  _PROJECTINFO._serialized_start=5740
  _PROJECTINFO._serialized_end=5820
  _COLLECTIONINFO._serialized_start=5822
  _COLLECTIONINFO._serialized_end=5911
  _BRANCHINFO._serialized_start=5913
  _BRANCHINFO._serialized_end=5990
  _LISTPROJECTSREQUEST._serialized_start=5992
  _LISTPROJECTSREQUEST._serialized_end=6013
  _LISTPROJECTSRESPONSE._serialized_start=6015
  _LISTPROJECTSRESPONSE._serialized_end=6083
  _LISTCOLLECTIONSREQUEST._serialized_start=6085
  _LISTCOLLECTIONSREQUEST._serialized_end=6193
  _LISTCOLLECTIONSRESPONSE._serialized_start=6195
  _LISTCOLLECTIONSRESPONSE._serialized_end=6272
  _DESCRIBEDATABASEREQUEST._serialized_start=6274
  _DESCRIBEDATABASEREQUEST._serialized_end=6355
  _DESCRIBECOLLECTIONREQUEST._serialized_start=6358
  _DESCRIBECOLLECTIONREQUEST._serialized_end=6512
  _DESCRIBEDATABASERESPONSE._serialized_start=6515
  _DESCRIBEDATABASERESPONSE._serialized_end=6683
  _DESCRIBECOLLECTIONRESPONSE._serialized_start=6686
  _DESCRIBECOLLECTIONRESPONSE._serialized_end=6866
  _PROJECTDESCRIPTION._serialized_start=6868
  _PROJECTDESCRIPTION._serialized_end=6888
  _COLLECTIONDESCRIPTION._serialized_start=6891
  _COLLECTIONDESCRIPTION._serialized_end=7066
  _PROJECTMETADATA._serialized_start=7068
  _PROJECTMETADATA._serialized_end=7085
  _DATABASEMETADATA._serialized_start=7087
  _DATABASEMETADATA._serialized_end=7105
  _COLLECTIONMETADATA._serialized_start=7107
  _COLLECTIONMETADATA._serialized_end=7127
  _COLLECTIONINDEX._serialized_start=7129
  _COLLECTIONINDEX._serialized_end=7213
  _FIELD._serialized_start=7215
  _FIELD._serialized_end=7236
  _BUILDCOLLECTIONINDEXREQUEST._serialized_start=7238
  _BUILDCOLLECTIONINDEXREQUEST._serialized_end=7320
  _BUILDCOLLECTIONINDEXRESPONSE._serialized_start=7322
  _BUILDCOLLECTIONINDEXRESPONSE._serialized_end=7401
  _BRANCHMETADATA._serialized_start=7403
  _BRANCHMETADATA._serialized_end=7419
  _CREATEAPPKEYREQUEST._serialized_start=7421
  _CREATEAPPKEYREQUEST._serialized_end=7494
  _CREATEAPPKEYRESPONSE._serialized_start=7496
  _CREATEAPPKEYRESPONSE._serialized_end=7566
  _UPDATEAPPKEYREQUEST._serialized_start=7568
  _UPDATEAPPKEYREQUEST._serialized_end=7653
  _UPDATEAPPKEYRESPONSE._serialized_start=7655
  _UPDATEAPPKEYRESPONSE._serialized_end=7725
  _APPKEY._serialized_start=7728
  _APPKEY._serialized_end=7896
  _LISTAPPKEYSREQUEST._serialized_start=7898
  _LISTAPPKEYSREQUEST._serialized_end=7935
  _LISTAPPKEYSRESPONSE._serialized_start=7937
  _LISTAPPKEYSRESPONSE._serialized_end=7999
  _DELETEAPPKEYREQUEST._serialized_start=8001
  _DELETEAPPKEYREQUEST._serialized_end=8051
  _DELETEAPPKEYRESPONSE._serialized_start=8053
  _DELETEAPPKEYRESPONSE._serialized_end=8092
  _ROTATEAPPKEYREQUEST._serialized_start=8094
  _ROTATEAPPKEYREQUEST._serialized_end=8144
  _ROTATEAPPKEYRESPONSE._serialized_start=8146
  _ROTATEAPPKEYRESPONSE._serialized_end=8208
  _TIGRIS._serialized_start=8211
  _TIGRIS._serialized_end=13901
# @@protoc_insertion_point(module_scope)
