from ..openapiv3 import OpenAPIv3_pb2 as _OpenAPIv3_pb2
from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
DOCUMENT_FIELD_NUMBER: _ClassVar[int]
OPERATION_FIELD_NUMBER: _ClassVar[int]
PROPERTY_FIELD_NUMBER: _ClassVar[int]
SCHEMA_FIELD_NUMBER: _ClassVar[int]
document: _descriptor.FieldDescriptor
operation: _descriptor.FieldDescriptor
property: _descriptor.FieldDescriptor
schema: _descriptor.FieldDescriptor
